@@ -1,11 +1,11 @@
-#from PythonPals.Button import *
-import Button
-#from PythonPals.questions import *
-import questions
+from PythonPals import Button
+#import Button
+from PythonPals import questions
+#import questions
 import pygame
 import pygame.gfxdraw
 import textwrap
-from PythonPals.player import Player, Coffee, Ruby, Eye
+from player import Player, Coffee, Ruby, Eye
 
 class Screen():
     def __init__(self, width, height):
